@@ -5,6 +5,8 @@ import PySimpleGUI as sg
 
 SOURCE_DIRECTORY = os.path.dirname(__file__)
 DATA_DIRECTORY = ".data"
+PPD = "PPD"
+PUE = "PUE"
 
 
 def add_file_handler():
@@ -56,6 +58,8 @@ class FacturacionLauncher:
             no_titlebar=True,
             modal=True,
             background_color=sg.theme_background_color(),
+            auto_close=True,
+            auto_close_duration=6,  # seconds
         )
 
     @staticmethod
@@ -74,7 +78,7 @@ class FacturacionLauncher:
         except Exception as ex:
             logging.exception(ex)
             self.window['console'].update(
-                str(ex)
+               f"Error al cargar la aplicación. {ex.__class__.__name__}: {ex}"
             )
             self.window.read()
             self.window.close()
