@@ -17,15 +17,15 @@ from satcfdi.printer import Representable
 from satcfdi.transform.catalog import CATALOGS
 from tabulate import tabulate
 
-from . import __version__
+from . import __version__, PPD, PUE
 from .client_validation import validar_client
 from .file_data_managers import ClientsManager, FacturasManager
 from .gui_functions import generate_ingresos, pago_factura, exportar_facturas, facturas_filename, \
     periodo_desc, generate_html_template, mf_pago_fmt, print_invoices, print_cfdis, print_cfdi_details, ajustes, ajustes_directory
 from .layout import make_layout, ActionButtonManager
-from .localdb import LocalDBSatCFDI
+from .localdb import LocalDBSatCFDI, LiquidatedState
 from .log_tools import log_line, log_item, cfdi_header, header_line, print_yaml
-from .mycfdi import get_all_cfdi, MyCFDI, move_to_folder, PPD, PUE
+from .mycfdi import get_all_cfdi, MyCFDI, move_to_folder
 from .utils import random_string, to_uuid, parse_date_period, parse_ym_date, load_certificate, to_int
 
 logging.getLogger("weasyprint").setLevel(logging.ERROR)
@@ -68,7 +68,7 @@ class FacturacionGUI:
 
         self.window = PySimpleGUI.Window(
             f"Facturación Masiva CFDI 4.0 {self.csd_signer.rfc}",
-            make_layout(True),
+            make_layout(bool(self.fiel_signer)),
             size=(1280, 800),
             resizable=True,
             font=("Courier New", 10, "bold"),
@@ -77,7 +77,7 @@ class FacturacionGUI:
         self.all_invoices = None
         self.local_db = LocalDBSatCFDI(
             enviar_a_partir=config['enviar_a_partir'],
-            saldar_a_partir=config['saldar_a_partir']
+            pagar_a_partir=config['pagar_a_partir']
         )
         # noinspection PyTypeChecker
         self.selected_satcfdi = None  # type: MyCFDI
@@ -182,7 +182,7 @@ class FacturacionGUI:
                     file_attachments=attachments
                 )
                 for r in notify_invoices:
-                    self.local_db.notificar_set(r.uuid, False)
+                    self.local_db.notified_set(r.uuid, True)
                 print_yaml({
                     "correo": subject,
                     "para": receptor["Email"]
@@ -260,9 +260,9 @@ class FacturacionGUI:
                       and i.estatus == "1"
         if is_enviable:
             self.window["email_notificada"].update(
-                "Por Enviar" if self.local_db.notificar(i) else " Enviada  ",
+                " Enviada  " if self.local_db.notified(i) else "Por Enviar",
                 visible=True,
-                button_color="red4" if self.local_db.notificar(i) else "green",
+                button_color="green" if self.local_db.notified(i) else "red4",
             )
         else:
             self.window["email_notificada"].update("", visible=False)
@@ -271,24 +271,25 @@ class FacturacionGUI:
         is_pendientable = i \
                           and i["Emisor"]["Rfc"] == self.csd_signer.rfc \
                           and i["TipoDeComprobante"] == "I" \
-                          and i["Fecha"] >= self.local_db.saldar_a_partir[i['MetodoPago']] \
+                          and i["Fecha"] >= self.local_db.pagar_a_partir[i['MetodoPago']] \
                           and i.estatus == "1" \
                           and (i["MetodoPago"] == PUE or i.saldo_pendiente) \
                           and i["Total"]
         if is_pendientable:
             self.window["pendiente_pago"].update(
-                "Por Saldar" if self.local_db.saldar(i) else " Saldada  ",
+                (" Pagada  " if i["MetodoPago"] == PUE else "Ignorada ") if self.local_db.liquidated(i) else "Por Pagar",
                 visible=True,
-                button_color="red4" if self.local_db.saldar(i) else "green",
+                button_color="green" if self.local_db.liquidated(i) else "red4",
             )
         else:
             self.window["pendiente_pago"].update("", visible=False)
 
         # PPD
         is_ppd_active = i \
+                        and i["Emisor"]["Rfc"] == self.csd_signer.rfc \
                         and i.get("MetodoPago") == PPD \
                         and i.estatus == "1" \
-                        and i["Emisor"]["Rfc"] == self.csd_signer.rfc
+                        and i.saldo_pendiente
         self.window["prepare_pago"].update(disabled=not is_ppd_active)
         self.window["fecha_pago_select"].update(disabled=not is_ppd_active)
         self.window["fecha_pago"].update(disabled=not is_ppd_active)
@@ -297,29 +298,30 @@ class FacturacionGUI:
 
     def print_satcfdis(self, cfdis):
         def info_fmt(i):
-            return "🗙" if i.estatus == '0' else ("📧" if self.local_db.notificar(i) else "")
+            return "" if self.local_db.notified(i) else "📧"
 
         if cfdis := sorted(cfdis, key=lambda i: (i["Fecha"], i.name), reverse=True):
             if self.window['detallado'].get():
-                for i in cfdis:
-                    print_yaml(i)
-                    self.local_db.describe(i)
+                for i, cfdi in enumerate(cfdis, start=1):
+                    log_item(f"FACTURA NUMERO: {i}")
+                    print_yaml(cfdi)
+                    self.local_db.describe(cfdi)
             else:
                 print_invoices(
                     [
                         [
-                            e,
-                            i['Receptor'].get('Nombre', '')[0:36],
-                            i['Receptor']['Rfc'],
-                            i.name,
-                            i["Fecha"].strftime("%Y-%m-%d"),
-                            i["Total"],
-                            self.local_db.saldar(i),
-                            mf_pago_fmt(i),
-                            i.uuid,
-                            info_fmt(i)
+                            i,
+                            cfdi['Receptor'].get('Nombre', '')[0:36],
+                            cfdi['Receptor']['Rfc'],
+                            cfdi.name,
+                            cfdi["Fecha"].strftime("%Y-%m-%d"),
+                            cfdi["Total"],
+                            self.local_db.liquidated_state(cfdi),
+                            mf_pago_fmt(cfdi),
+                            cfdi.uuid,
+                            info_fmt(cfdi)
                         ]
-                        for e, i in enumerate(cfdis, start=1)
+                        for i, cfdi in enumerate(cfdis, start=1)
                     ]
                 )
             if len(cfdis) == 1:
@@ -357,6 +359,10 @@ class FacturacionGUI:
 
                 action_name, action_items = self.action_button_manager.clear()
 
+                if event in ("prepare_correos", "prepare_clientes", "prepare_facturas", "crear_facturas",
+                             "inicio_enter", "final_enter", "preparar_ajuste_anual", "recuperar_emitidas", "recuperar_recibidas"):
+                    self.set_selected_satcfdi([])
+
                 match event:
                     case "folio":
                         self.set_folio(to_int(values["folio"]))
@@ -502,7 +508,7 @@ class FacturacionGUI:
                             )
 
                     case "status_sat":
-                        self.header("STATUS")
+                        self.header("STATUS SAT")
                         if i := self.selected_satcfdi:
                             estado = self.local_db.status_sat(i, update=True)
                             self.print_satcfdis([i])
@@ -510,19 +516,22 @@ class FacturacionGUI:
 
                     case "pendiente_pago":
                         if i := self.selected_satcfdi:
-                            st = self.local_db.saldar_flip(i)
+                            st = self.local_db.liquidated_flip(i)
                             self.console.update("")
                             self.header(self.window[event].ButtonText.upper())
                             self.print_satcfdis([i])
-                            print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}SALDADA")
+                            if i["MetodoPago"] == PUE:
+                                print(f"FACTURA MARCADA COMO {'' if st else '-NO- '}PAGADA")
+                            else:
+                                print(f"FACTURA MARCADA COMO {'' if st else '-NO- '}IGNORADA")
 
                     case "email_notificada":
                         if i := self.selected_satcfdi:
-                            st = self.local_db.notificar_flip(i)
+                            st = self.local_db.notified_flip(i)
                             self.console.update("")
                             self.header(self.window[event].ButtonText.upper())
                             self.print_satcfdis([i])
-                            print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}NOTIFICADA")
+                            print(f"FACTURA MARCADA COMO {'' if st else '-NO- '}NOTIFICADA")
 
                     case "prepare_correos":
                         self.header("CORREOS")
@@ -534,7 +543,7 @@ class FacturacionGUI:
                         cfdi_correos = []
                         for receptor_rfc, notify_invoices in itertools.groupby(
                                 sorted(
-                                    (i for i in a_invoices.values() if i.estatus == "1" and self.local_db.notificar(i)),
+                                    (i for i in a_invoices.values() if i.estatus == "1" and not self.local_db.notified(i)),
                                     key=lambda r: r["Receptor"]["Rfc"]
                                 ),
                                 lambda r: r["Receptor"]["Rfc"]
@@ -544,9 +553,7 @@ class FacturacionGUI:
                             def fac_iter():
                                 for i in self.get_all_invoices().values():
                                     if i["Emisor"]["Rfc"] == self.csd_signer.rfc \
-                                            and i["TipoDeComprobante"] == "I" \
-                                            and i.estatus == '1' \
-                                            and self.local_db.saldar(i) \
+                                            and self.local_db.liquidated_state(i) == LiquidatedState.NO \
                                             and i["Fecha"] < dp \
                                             and i["Receptor"]["Rfc"] == receptor_rfc:
                                         yield i
@@ -585,6 +592,7 @@ class FacturacionGUI:
                             print("No hay correos pendientes de enviar")
 
                     case "crear_facturas":
+                        self.console.update(autoscroll=True)
                         self.header(f"PROCESAR {action_name.upper()}", clear=False)
                         res = PySimpleGUI.popup(
                             f"Estas seguro que quieres crear {len(action_items)} {action_name}?",
@@ -596,6 +604,7 @@ class FacturacionGUI:
                             print("FIN")
                         else:
                             print("OPERACION CANCELADA")
+                        self.console.update(autoscroll=False)
 
                     case "facturas_pendientes":
                         self.header("FACTURAS PENDIENTES")
@@ -603,9 +612,7 @@ class FacturacionGUI:
                         def fac_iter():
                             for i in self.get_all_invoices().values():
                                 if i["Emisor"]["Rfc"] == self.csd_signer.rfc \
-                                        and i["TipoDeComprobante"] == "I" \
-                                        and i.estatus == '1' \
-                                        and self.local_db.saldar(i):
+                                        and self.local_db.liquidated_state(i) == LiquidatedState.NO:
                                     yield i
 
                         self.print_satcfdis(fac_iter())
