@@ -2,9 +2,14 @@ import yaml
 from satcfdi import Code
 
 
+class NoAliasDumper(yaml.SafeDumper):
+    def ignore_aliases(self, data):
+        return True
+
+
 def print_yaml(data):
     print(
-        yaml.safe_dump(data, allow_unicode=True, width=1280, sort_keys=False)
+        yaml.dump(data, Dumper=NoAliasDumper, allow_unicode=True, width=1280, sort_keys=False)
     )
 
 
@@ -18,7 +23,7 @@ def log_email(receptor, notify_invoices, facturas_pendientes):
 
 
 def header_line(text):
-    ln = (150 - len(text)) // 2
+    ln = (151 - len(text)) // 2
     return ("=" * ln) + " " + text + " " + ("=" * ln)
 
 
@@ -29,7 +34,7 @@ def log_line(text):
 
 
 def log_item(text):
-    ln = (150 - len(text)) // 2
+    ln = (151 - len(text)) // 2
     print(
         ("*" * ln) + " " + text + " " + ("*" * ln),
     )
