@@ -15,16 +15,10 @@ ALL_INVOICES = 'all_invoices'
 ALL_RETENCIONES = 'all_retenciones'
 logger = logging.getLogger(__name__)
 
-PPD = "PPD"
-PUE = "PUE"
-
 
 class MyCFDI(SatCFDI):
     local_db = None
 
-    def consulta_estado(self):
-        return self.local_db.status_sat(self)
-
     @SatCFDI.estatus.getter
     def estatus(self) -> str:
         Estatus = {
